@@ -27,7 +27,8 @@ import (
 	"os"
 
 	"github.com/pkg/errors"
-	"github.com/shenwei356/unikmer"
+	"github.com/shenwei356/unik/v5"
+
 	"github.com/spf13/cobra"
 )
 
@@ -83,11 +84,11 @@ Attentions:
 			w.Close()
 		}()
 
-		var writer *unikmer.Writer
+		var writer *unik.Writer
 
 		var infh *bufio.Reader
 		var r *os.File
-		var reader0 *unikmer.Reader
+		var reader0 *unik.Reader
 		var code uint64
 		var taxid uint32
 		var k int = -1
@@ -107,7 +108,7 @@ Attentions:
 				checkError(err)
 				defer r.Close()
 
-				reader, err := unikmer.NewReader(infh)
+				reader, err := unik.NewReader(infh)
 				checkError(errors.Wrap(err, file))
 
 				if k == -1 {
@@ -119,20 +120,20 @@ Attentions:
 
 					var mode uint32
 					if sortedKmers { // || (len(files) == 1 && reader.IsSorted()) {
-						mode |= unikmer.UnikSorted
+						mode |= unik.UnikSorted
 					} else if opt.Compact && !hashed {
-						mode |= unikmer.UnikCompact
+						mode |= unik.UnikCompact
 					}
 					if canonical {
-						mode |= unikmer.UnikCanonical
+						mode |= unik.UnikCanonical
 					}
 					if hasTaxid && !hasGlobalTaxid {
-						mode |= unikmer.UnikIncludeTaxID
+						mode |= unik.UnikIncludeTaxID
 					}
 					if hashed {
-						mode |= unikmer.UnikHashed
+						mode |= unik.UnikHashed
 					}
-					writer, err = unikmer.NewWriter(outfh, k, mode)
+					writer, err = unik.NewWriter(outfh, k, mode)
 					checkError(err)
 					writer.SetMaxTaxid(maxUint32N(reader.GetTaxidBytesLength())) // follow reader
 					if hasGlobalTaxid {
