@@ -81,6 +81,9 @@ K-mer sketches:
 			hashed = true
 			log.Warning("flag -H/--hash is switched on for k > 32")
 		}
+		if hashed && k > 64 {
+			checkError(fmt.Errorf("k-mer size (%d) should be <=64", k))
+		}
 
 		scale := getFlagPositiveInt(cmd, "scale")
 		if scale > 1<<31-1 {
@@ -619,7 +622,7 @@ func init() {
 	countCmd.Flags().IntP("minimizer-w", "W", 0, `minimizer window size`)
 	countCmd.Flags().IntP("syncmer-s", "S", 0, `closed syncmer length`)
 
-	countCmd.Flags().BoolP("linear", "l", false, `output k-mers in linear order`)
+	countCmd.Flags().BoolP("linear", "l", false, `output k-mers in linear order, duplicate k-mers are not removed`)
 
 	countCmd.SetUsageTemplate(usageTemplate("-K -k <k> -u -s [-t <taxid>] <seq files> -o <out prefix>"))
 
