@@ -30,7 +30,9 @@ import (
 	"strings"
 
 	"github.com/pkg/errors"
-	"github.com/shenwei356/unikmer"
+
+	"github.com/shenwei356/bio/taxdump"
+	"github.com/shenwei356/unik/v5"
 	"github.com/shenwei356/util/pathutil"
 	"github.com/shenwei356/util/stringutil"
 	"github.com/spf13/cobra"
@@ -46,7 +48,7 @@ var rfilterCmd = &cobra.Command{
 Attentions:
   1. Flag -L/--lower-than and -H/--higher-than are exclusive, and can be
      used along with -E/--equal-to which values can be different.
-  2. A list of pre-ordered ranks is in ~/.taxonkit/ranks.txt, you can use
+  2. A list of pre-ordered ranks is in ~/.unikmer/ranks.txt, you can use
      your list by -r/--rank-file, the format specification is below.
   3. All ranks in taxonomy database should be defined in rank file.
   4. Ranks can be removed with black list via -B/--black-list.
@@ -110,6 +112,9 @@ Rank file:
 
 		if saveNorank {
 			discardNoRank = true
+			if !discardNoRank {
+				log.Infof("flag -N/--discard-noranks is switched on when using -n/--save-predictable-norank")
+			}
 
 			if lower == "" {
 				checkError(fmt.Errorf("flag -n/--save-predictable-norank only works along with -L/--lower-than"))
@@ -197,13 +202,16 @@ Rank file:
 
 		if opt.Verbose {
 			if discardNoRank {
-				log.Debugf("ranks without order will be discarded: %s", strings.Join(noRanksList, ", "))
+				log.Infof("ranks without order will be discarded: %s", strings.Join(noRanksList, ", "))
+			}
+			if saveNorank {
+				log.Infof("but some predictable 'no rank' will be saved with -n/--save-predictable-norank)")
 			}
 			if discardRoot {
-				log.Debugf("root rank without order will be discarded")
+				log.Infof("root rank without order will be discarded")
 			}
 			if len(blackListRanks) > 0 {
-				log.Debugf("ranks in black list will be discarded: %s", strings.Join(blackListRanks, ", "))
+				log.Infof("ranks in black list will be discarded: %s", strings.Join(blackListRanks, ", "))
 			}
 		}
 
@@ -223,11 +231,11 @@ Rank file:
 			w.Close()
 		}()
 
-		var writer *unikmer.Writer
+		var writer *unik.Writer
 
 		var infh *bufio.Reader
 		var r *os.File
-		var reader0 *unikmer.Reader
+		var reader0 *unik.Reader
 		var code uint64
 		var taxid uint32
 		var k int = -1
@@ -247,7 +255,7 @@ Rank file:
 				checkError(err)
 				defer r.Close()
 
-				reader, err := unikmer.NewReader(infh)
+				reader, err := unik.NewReader(infh)
 				checkError(errors.Wrap(err, file))
 
 				hasTaxid = !opt.IgnoreTaxid && reader.HasTaxidInfo()
@@ -259,8 +267,8 @@ Rank file:
 					}
 
 					mode := reader.Flag
-					mode |= unikmer.UnikIncludeTaxID
-					writer, err = unikmer.NewWriter(outfh, k, mode)
+					mode |= unik.UnikIncludeTaxID
+					writer, err = unik.NewWriter(outfh, k, mode)
 					checkError(errors.Wrap(err, outFile))
 					writer.SetMaxTaxid(maxUint32N(reader.GetTaxidBytesLength())) // follow reader
 				} else {
@@ -334,7 +342,7 @@ func init() {
 }
 
 type rankFilter struct {
-	taxondb *unikmer.Taxonomy
+	taxondb *taxdump.Taxonomy
 
 	dbRanks   map[string]interface{}
 	rankOrder map[string]int
@@ -361,7 +369,7 @@ type rankFilter struct {
 	cache map[uint32]bool
 }
 
-func newRankFilter(taxondb *unikmer.Taxonomy, rankOrder map[string]int, noRanks map[string]interface{},
+func newRankFilter(taxondb *taxdump.Taxonomy, rankOrder map[string]int, noRanks map[string]interface{},
 	lower string, higher string, equals []string, blackList []string, discardNorank bool, saveKnownNoRank bool) (*rankFilter, error) {
 
 	if lower != "" && higher != "" {
