@@ -212,6 +212,10 @@ Attention:
 						}
 					}
 
+					if len(record.Seq.Seq) < k {
+						continue
+					}
+
 					if hashed {
 						iter, err = sketches.NewHashIterator(record.Seq, k, true, circular)
 					} else {
@@ -321,6 +325,10 @@ Attention:
 					}
 				}
 
+				if len(record.Seq.Seq) < k {
+					continue
+				}
+
 				length0 = len(record.Seq.Seq)
 
 				if circular { // concat two copies of sequence
